@@ -1,7 +1,7 @@
 from setuptools_scm import format_version
 from setuptools_scm.hg import archival_to_version, parse
 from setuptools_scm import integration
-
+from setuptools_scm.config import Configuration
 import pytest
 
 
@@ -16,7 +16,9 @@ def wd(wd):
 archival_mapping = {
     "1.0": {"tag": "1.0"},
     "1.1.dev3+h000000000000": {
-        "latesttag": "1.0", "latesttagdistance": "3", "node": "0" * 20
+        "latesttag": "1.0",
+        "latesttagdistance": "3",
+        "node": "0" * 20,
     },
     "0.0": {"node": "0" * 20},
     "1.2.2": {"tag": "release-1.2.2"},
@@ -26,7 +28,8 @@ archival_mapping = {
 
 @pytest.mark.parametrize("expected,data", sorted(archival_mapping.items()))
 def test_archival_to_version(expected, data):
-    version = archival_to_version(data)
+    config = Configuration()
+    version = archival_to_version(data, config=config)
     assert (
         format_version(
             version, version_scheme="guess-next-dev", local_scheme="node-and-date"
